summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJett Rink <jettrink@chromium.org>2018-01-25 16:07:39 -0700
committerchrome-bot <chrome-bot@chromium.org>2018-01-26 10:58:55 -0800
commita5c21c4ffe16eeee3da97b1138aa6b5556983e7d (patch)
tree7d3ab6d37765f8bded2d194ef486c992e09f61dd
parent9c06f2f1c2ba3da9545f4ee5e47d7d0faf308435 (diff)
downloadchrome-ec-a5c21c4ffe16eeee3da97b1138aa6b5556983e7d.tar.gz
usb pd: Increasing delay for Rp time on CC lines
Some chargers don't respect the SRC.Open state within the 20ms allotted by the usb spec. The LiteOn Charger seems to notice after ~120ms bumping to 200ms so we cutoff Vbus for even ill-behaved chargers. We expect to brown out in the sleep. BRANCH=none TEST=LiteOn charge will disconnect now BUG=b:72510370 Change-Id: Ief0e999ed52f39420eed5f07432273e741a14c7e Signed-off-by: Jett Rink <jettrink@chromium.org> Reviewed-on: https://chromium-review.googlesource.com/886833 Reviewed-by: Vincent Palatin <vpalatin@chromium.org> Reviewed-by: Shawn N <shawnn@chromium.org>
-rw-r--r--common/usb_pd_protocol.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/common/usb_pd_protocol.c b/common/usb_pd_protocol.c
index 5696f9559c..9aec67cbb6 100644
--- a/common/usb_pd_protocol.c
+++ b/common/usb_pd_protocol.c
@@ -1829,9 +1829,9 @@ static void pd_partner_port_reset(int port)
(RESET_FLAG_BROWNOUT | RESET_FLAG_POWER_ON))
return;
/* Provide Rp for 100 msec. or until we no longer have VBUS. */
tcpm_set_cc(port, TYPEC_CC_RP);
- timeout = get_time().val + 100 * MSEC;
+ timeout = get_time().val + 200 * MSEC;
while (get_time().val < timeout && pd_is_vbus_present(port))
msleep(10);
@@ -1829,9 +1829,9 @@ static void pd_partner_port_reset(int port)
(RESET_FLAG_BROWNOUT | RESET_FLAG_POWER_ON))
return;
- /* Provide Rp for 100 msec. or until we no longer have VBUS. */
+ /* Provide Rp for 200 msec. or until we no longer have VBUS. */
tcpm_set_cc(port, TYPEC_CC_RP);